@@ -1,9 +1,11 @@
+# -*- coding: utf-8 -*-
 import re
 import textwrap
 
 from lxml.html import parse
 
 from mtglib.card_renderer import Card
+from mtglib.constants import RARITY_NAMES
 from mtglib.functions import is_string
 
 __all__ = ['CardExtractor', 'Card']
@@ -67,25 +69,29 @@ class CardExtractor(object):
 
     def extract_many(self):
         cards = []
+        p = [t for t in self.document.cssselect('td') if not t.get('colspan')]
+        card = Card()
+        for label, value in zip(p[0::2], p[1::2]):
+            attr = label.text_content().strip(': \n\r') \
+                                       .replace(' ', '_').lower()
+            if attr == 'name':
+                card.name = value.text_content().strip()
+            if attr == 'type':
+                card.types, card.subtypes = self.types(value.text_content().strip())
+            if attr == 'cost':
+                card.mana_cost = value.text_content().strip()
+            if attr == 'loyalty':
+                card.loyalty = value.text_content().strip(' \n\r()')
+            if attr == 'pow/tgh' and value.text_content().strip('\n\r() '):
+                card.power, card.toughness = self.split_pow_tgh(value.text_content().strip('\n\r() '))
+            if attr == 'rules_text':
+                card.rules_text = value.text_content().strip().replace('\n', ' ; ')
+            if attr == 'set/rarity':
+                card.printings = self.printings_text(value)
 
-        for item in self.document.cssselect('tr.cardItem'):
-            for c in item.cssselect('div.cardInfo'):
+                # kind of a hack, set/rarity is always last.
+                cards.append(card)
                 card = Card()
-                card.name = self.text_field(c, '.cardTitle')
-                card.mana_cost = self.symbol_field(c, '.manaCost img')
-                typeline = self.text_field(c, '.typeLine')
-                t = [l.strip() for l in typeline.split('\n') if l.strip()]
-                card.types = t.pop(0)
-                if t:
-                    number = t.pop(0).strip('()')
-                    if '/' in number:
-                        card.power, card.toughness = self.split_pow_tgh(number)
-                    else:
-                        card.loyalty = number
-                card.types, card.subtypes = self.types(card.types)
-                card.rules_text = self.box_field(c, 'div.rulesText p', ' ; ')
-                card.printings = self.printings(item, 'td.rightCol img')
-            cards.append(card)
         return cards
 
     def split_pow_tgh(self, text):
@@ -93,7 +99,7 @@ class CardExtractor(object):
 
         Correctly accounts for curly braces to denote fractions.
         E.g., '2/2' --> ['2', '2']
-        '3{1/2}/3{1/2}' --> ['3{1/2}', '3{1/2']
+        '3{1/2}/3{1/2}' --> ['3{1/2}', '3{1/2}']
 
         """
         return [n for n in re.split(r"/(?=([^{}]*{[^{}]*})*[^{}]*$)", text)
@@ -114,6 +120,15 @@ class CardExtractor(object):
         typ = typeline.strip().split(' ')
         return typ, sub
 
+    def printings_text(self, element):
+        printings = []
+        for t in element.text_content().strip().split(','):
+            for r in RARITY_NAMES:
+                if t.endswith(r):
+                    printings.append( (t.replace(' ' + r, '').strip(), r))
+                    break
+        return printings
+
     def printings(self, element, css):
         printings = []
         for img in element.cssselect(css):
@@ -154,6 +169,11 @@ class CardExtractor(object):
                     attributes[attr] = self.symbol_field(value, 'img')
                 elif attr == 'types':
                     attributes['types'], attributes['subtypes'] = self.types(value.text_content().strip())
+                elif attr == 'community_rating':
+                    attributes['community_rating'] = self.text_field(
+                        value, 'span.textRatingValue')
+                    attributes['community_votes'] = self.text_field(
+                        value, 'span.totalVotesValue')
                 else:
                     attributes[attr] = value.text_content().strip()
 
@@ -175,9 +195,11 @@ class Symbol(object):
         self.text = text
         self.specials = {'Untap': 'Q',
                          'Blue': 'U',
-                         'Snow': 'S}i',
+                         'Snow': 'S',
                          'Variable Colorless': 'X',
-                         'Two': '2'}
+                         'Two': '2',
+                         'Infinite': u'∞',
+                         '500': '(Half W)'}
 
     @property
     def short(self):
@@ -189,6 +211,8 @@ class Symbol(object):
             return self.phyrexian
         elif self.text.isdigit():
             return self.text
+        elif self.is_half:
+            return self.half
         return self.text[:1]
 
     @property
@@ -204,13 +228,21 @@ class Symbol(object):
     def is_hybrid(self):
         return ' or ' in self.text
 
+    @property
+    def is_half(self):
+        return 'Half' in self.text
+
     @property
     def hybrid(self):
         return '({0})'.format('/'.join(
                 Symbol(l).short for l in self.text.split(' or ')))
 
+    @property
+    def half(self):
+        return 'Half {0}'.format(Symbol(self.text.split(' ')[-1]).short)
+
     @property
     def textbox(self):
-        base = '{{{0}}}'.format(self.short)
+        base = u'{{{0}}}'.format(self.short)
         if '/' in base: return base.lower()
         else: return base
\ No newline at end of file
