@@ -1,17 +1,16 @@
 base_url = ('http://gatherer.wizards.com/Pages/Search/Default.aspx'
-            '?output=standard&action=advanced&')
+            '?output=spoiler&method=text&action=advanced&')
 
 random_url = 'http://gatherer.wizards.com/Pages/Card/Details.aspx?action=random'
 
-card_flags = ['text', 'color', 'subtype', 'type', 'set', 'cmc', 'power',
-              'tough', 'rarity', 'name', 'block']
-
-TYPES = ['artifact', 'basic', 'creature', 'enchantment', 'instant', 'land',
-         'legendary', 'ongoing', 'plane', 'planeswalker', 'scheme', 'snow',
-         'sorcery', 'tribal', 'vanguard', 'world']
+TYPES = set(['artifact', 'basic', 'creature', 'enchantment', 'instant', 'land',
+             'legendary', 'ongoing', 'plane', 'planeswalker', 'scheme', 'snow',
+             'sorcery', 'tribal', 'vanguard', 'world'])
 
 COLORS = {'w': 'W', 'u': 'U', 'b': 'B', 'r': 'R', 'g': 'G', 'c': 'C'}
 
+RARITY_NAMES = ['Mythic Rare', 'Common', 'Uncommon', 'Rare']
+
 RARITIES = {
     'c': 'C',
     'common': 'C',
